==> haskell-jira-wiki-markup-1.5.1-121.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-jira-wiki-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 jira-wiki-markup
version:              1.5.1
visibility:           public
id:                   jira-wiki-markup-1.5.1-4U0K4voB4o1DNCAMmJmtYy
key:                  jira-wiki-markup-1.5.1-4U0K4voB4o1DNCAMmJmtYy
license:              MIT
copyright:            © 2019–2023 Albert Krewinkel
maintainer:           tarleb@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/jira-wiki-markup
synopsis:             Handle Jira wiki markup
description:
    Parse jira wiki text into an abstract syntax tree for easy
    transformation to other formats.

category:             Text
abi:                  9f1a5e9aaa51146d26b20e63e3b32ca4
exposed:              True
exposed-modules:
    Text.Jira.Markup Text.Jira.Parser Text.Jira.Parser.Block
    Text.Jira.Parser.Core Text.Jira.Parser.Inline
    Text.Jira.Parser.PlainText Text.Jira.Parser.Shared
    Text.Jira.Printer

import-dirs:          /usr/lib/ghc-9.6.6/site-local/jira-wiki-markup-1.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/jira-wiki-markup-1.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/jira-wiki-markup-1.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-jira-wiki-markup
hs-libraries:         HSjira-wiki-markup-1.5.1-4U0K4voB4o1DNCAMmJmtYy
depends:              base-4.18.2.1 mtl-2.3.1 parsec-3.1.16.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-jira-wiki-markup/html/jira-wiki-markup.haddock

haddock-html:         /usr/share/doc/haskell-jira-wiki-markup/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-jira-wiki-markup-1.5.1-122-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-jira-wiki-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 jira-wiki-markup
version:              1.5.1
visibility:           public
id:                   jira-wiki-markup-1.5.1-HMjcwwVsyZkCbX6tWLmurK
key:                  jira-wiki-markup-1.5.1-HMjcwwVsyZkCbX6tWLmurK
license:              MIT
copyright:            © 2019–2023 Albert Krewinkel
maintainer:           tarleb@zeitkraut.de
author:               Albert Krewinkel
homepage:             https://github.com/tarleb/jira-wiki-markup
synopsis:             Handle Jira wiki markup
description:
    Parse jira wiki text into an abstract syntax tree for easy
    transformation to other formats.

category:             Text
abi:                  7047ca44e2dd4230902168702ff71eaa
exposed:              True
exposed-modules:
    Text.Jira.Markup Text.Jira.Parser Text.Jira.Parser.Block
    Text.Jira.Parser.Core Text.Jira.Parser.Inline
    Text.Jira.Parser.PlainText Text.Jira.Parser.Shared
    Text.Jira.Printer

import-dirs:          /usr/lib/ghc-9.6.6/site-local/jira-wiki-markup-1.5.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/jira-wiki-markup-1.5.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/jira-wiki-markup-1.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-jira-wiki-markup
hs-libraries:         HSjira-wiki-markup-1.5.1-HMjcwwVsyZkCbX6tWLmurK
depends:              base-4.18.2.1 mtl-2.3.1 parsec-3.1.16.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-jira-wiki-markup/html/jira-wiki-markup.haddock

haddock-html:         /usr/share/doc/haskell-jira-wiki-markup/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
